# EIDA Consistency Report: `KOERI`

- Seed: `859306`
- Time: `2025-09-08T17:27:26.714781+00:00`
- Epochs requested: `20`
- Candidates requested: `20`
- Candidates tested: `None`
- Station queries performed: `None`
- Duration/epoch: `600 s`
- Total checks run: `20`
- Consistent: `10`
- Inconsistent: `10`
- Score: **50.0 %**

## Inconsistency Breakdown
- Availability says YES, Dataselect says NO: `0`
- Availability says NO, Dataselect says YES: `10`

## Dataselect Response Types
- **MultiTrace**: `3`
- **NoTrace**: `2`
- **SingleTrace**: `15`

---

## Detailed Results
### `KO.CAVI..BHN`
- Window: `2013-04-09T21:49:19 → 2013-04-09T21:59:19`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `KO.YUVA..EHN`
- Window: `2017-12-17T19:36:26 → 2017-12-17T19:46:26`
- Availability: `True`
- Dataselect: `True`
- Type: `MultiTrace`
- Status: `OK`
- Consistent: `✔️`

### `KO.ERBG..HNE`
- Window: `2022-09-03T02:48:17 → 2022-09-03T02:58:17`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `KO.MAEG..HNN`
- Window: `2025-09-02T20:38:42 → 2025-09-02T20:48:42`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `KO.GOMA..HNN`
- Window: `2018-09-05T17:26:14 → 2018-09-05T17:36:14`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `KO.ESPY..BHZ`
- Window: `2009-06-14T19:26:40 → 2009-06-14T19:36:40`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `KO.TUNC..HNN`
- Window: `2023-12-05T18:50:49 → 2023-12-05T19:00:49`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `KO.LAP..HHN`
- Window: `2016-01-16T03:59:56 → 2016-01-16T04:09:56`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `KO.YOZ..HHN`
- Window: `2024-11-21T05:27:16 → 2024-11-21T05:37:16`
- Availability: `True`
- Dataselect: `True`
- Type: `MultiTrace`
- Status: `OK`
- Consistent: `✔️`

### `KO.KOUK..HNE`
- Window: `2023-09-11T04:34:22 → 2023-09-11T04:44:22`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `KO.KULA..BHN`
- Window: `2008-05-19T16:28:19 → 2008-05-19T16:38:19`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `KO.CTKS..BHE`
- Window: `2009-10-08T16:53:58 → 2009-10-08T17:03:58`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `KO.SILV..HNZ`
- Window: `2023-10-16T06:45:04 → 2023-10-16T06:55:04`
- Availability: `False`
- Dataselect: `True`
- Type: `MultiTrace`
- Status: `OK`
- Consistent: `❌`

### `KO.BAKL..HHZ`
- Window: `2021-06-07T11:00:48 → 2021-06-07T11:10:48`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `KO.EZNE..HNZ`
- Window: `2023-09-12T10:44:14 → 2023-09-12T10:54:14`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `KO.CUKT..HNZ`
- Window: `2024-08-19T22:45:49 → 2024-08-19T22:55:49`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `KO.BAYT..HHE`
- Window: `2022-12-14T02:56:22 → 2022-12-14T03:06:22`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `KO.GOKC..HNE`
- Window: `2023-04-17T20:01:22 → 2023-04-17T20:11:22`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `KO.ASYA..HNE`
- Window: `2025-06-14T00:21:13 → 2025-06-14T00:31:13`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `KO.TZLA..HNE`
- Window: `2024-09-21T21:49:43 → 2024-09-21T21:59:43`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`
